*********
Changelog
*********

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

============
[Unreleased]
============

--------------------
[0.0.8] - 2021-02-06
--------------------

~~~~~~~
Changed
~~~~~~~

* Working version published to pypi and conda.

--------------------
[0.0.1] - 2021-01-11
--------------------

~~~~~
Added
~~~~~

* Initial working code.
